<?php
/**
 * @package Extension iubenda Cookie Law Solution for Joomla! greater than 2.5
 * @version 1.2.5
 * @author iubenda
 * @copyright (C) 2018 iubenda
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
**/

defined( '_JEXEC' ) || die();

jimport( 'joomla.plugin.plugin' );
jimport( 'joomla.language.language' );
jimport( 'joomla.form.formfield' );

class JFormFieldJSCode extends JFormField {
	protected $type = 'JSCode';

	public function getInput() {
		$languages = JLanguage::getKnownLanguages();
		$field = '';

		foreach( $languages as $lang_id => $language ) {
			$value = isset( $this->value[$lang_id] ) ? $this->value[$lang_id] : '';
			$field .= '<div><label for="' . $this->id . '-' . $lang_id . '"></label><textarea name="' . $this->name . '[' . $lang_id . ']" id="' . $this->id . '-' . $lang_id . '" class="iubenda-textarea" style="width: 530px; height: 210px;">' . htmlentities( $value ) . '</textarea><p style="margin: 10px 0;">' . $language['name'] . '</p></div>';
		}

		return $field;
	}
}

class PlgSystemIubenda extends JPlugin {
	function __construct( & $subject, $config ) {
		parent::__construct( $subject, $config );
		$this->loadLanguage();
	}

	function onAfterRender() {
		// passing this parameter on a website will disactivate the iubenda script and therefore avoid all parsing/replacing operations
		if ( isset( $_GET[ 'iub_no_parse' ] ) || isset( $_SERVER['HTTP_X_REQUESTED_WITH'] ) )
			return true;

		$app = JFactory::getApplication();

		// front page?
		if ( $app->isSite() ) {
			require( dirname( __FILE__ ) . '/iubenda-cookie-class/iubenda.class.php' );

			// check whether to run parser or not
			if ( ( (bool) $this->params->get( 'iubenda_no_parse' ) && iubendaParser::consent_given() ) || iubendaParser::bot_detected() )
				return true;

			// including iubenda class and simpleHTMLDom
			$content = JResponse::getBody();

			if ( strpos( $content, '<html' ) === false || strpos( $content, '<html' ) > 200 )
				return true;

			// get langauge data
			$lang = JFactory::getLanguage();
			$current_lang = $lang->getTag();
			$codes = $this->params->get( 'iubenda_code' );

			// check current language
			if ( isset( $codes->$current_lang ) )
				$iub_code = $codes->$current_lang;
			// check any language
			elseif ( ! empty( $codes ) )
				$iub_code = reset( $codes );
			// nothing?
			else 
				$iub_code = '';

			$iub_code .="\n
			<script type='text/javascript'>
				var iCallback = function(){};

				if('callback' in _iub.csConfiguration) {
					if('onConsentGiven' in _iub.csConfiguration.callback) iCallback = _iub.csConfiguration.callback.onConsentGiven;

					_iub.csConfiguration.callback.onConsentGiven = function()
					{
						iCallback();

						jQuery('noscript._no_script_iub').each(function (a, b) { var el = jQuery(b); el.after(el.html()); });
					};
				};
			</script>";

			$custom_scripts = array_filter( array_map( 'trim', explode( "\n", str_replace( "\r", '', $this->params->get( 'iubenda_custom_scripts' ) ) ) ) );
			$custom_iframes = array_filter( array_map( 'trim', explode( "\n", str_replace( "\r", '', $this->params->get( 'iubenda_custom_iframes' ) ) ) ) );

			if ( (int) $this->params->get( 'iubenda_experimental_parser' ) === 1 ) {
				$iubenda = new iubendaParser( mb_convert_encoding( $content, 'HTML-ENTITIES', 'UTF-8' ), array( 'type' => 'faster', 'scripts' => $custom_scripts, 'iframes' => $custom_iframes ) );

				// render output
				$content = $iubenda->parse();

				$content .= "<!-- IUBENDA PRIMARY PARSING ENGINE -->";
			} else {
				$iubenda = new iubendaParser( $content, array( 'type' => 'page', 'scripts' => $custom_scripts, 'iframes' => $custom_iframes ) );

				// render output
				$content = $iubenda->parse();

				$content .= "<!-- IUBENDA SECONDARY PARSING ENGINE -->";
			}

			$content = str_replace("</head>", $iub_code."</head>", $content);

			JResponse::setBody( $content."<!-- IUBENDA PLUGIN ACTIVE -->" );
		}

		return true;
	}
}